arrc.layers
===========

.. automodule:: arrc.layers

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   additive_noise
   amp_scaling
   arc_face
   attention_pool_1d
   gated_convolution
   l2_normalization
   metric_embedding
   nan_check_layer
   rescale_layer
   time_shift
